@@ -261,7 +261,6 @@ int getpathtoprog(char *buffer, int bufsize, char *prog)
 {
     char pathtest[PATH_MAX];
     char delims[]=":\t\n";
-    struct stat bufstat;
     char pathenv[4096];
     char *saveptr=0;
     char *result;
@@ -276,7 +275,7 @@ int getpathtoprog(char *buffer, int bufsize, char *prog)
     for(i=0; result != NULL; i++)
     {
         snprintf(pathtest, sizeof(pathtest), "%s/%s", result, prog);
-        if (stat(pathtest, &bufstat)==0 && access(pathtest, X_OK)==0)
+        if (access(pathtest, X_OK)==0)
         {
             snprintf(buffer, bufsize, "%s", pathtest);
             return 0;
@@ -403,9 +402,10 @@ int exec_command(char *command, int cmdbufsize, int *exitst, char *stdoutbuf, in
         if ((stderrbuf!=NULL) && (errpos+1 < stderrsize))
             read(mystderr, stderrbuf+errpos, stderrsize-errpos-1);
         
-        msgprintf(MSG_VERB1, "command [%s] returned %d\n", command, WEXITSTATUS(status));
+        status = WIFSIGNALED(status) ? 128 + WTERMSIG(status) : WEXITSTATUS(status);
+        msgprintf(MSG_VERB1, "command [%s] returned %d\n", command, status);
         if (exitst)
-            *exitst=WEXITSTATUS(status);
+            *exitst=status;
         
         if ((stdoutbuf!=NULL) && (outpos>0))
             msgprintf(MSG_DEBUG1, "\n----stdout----\n%s\n----stdout----\n\n", stdoutbuf);
