@@ -53,8 +53,6 @@ int reiser4_mkfs(cdico *d, char *partition, char *fsoptions, char *mkfslabel, ch
     // ---- set the advanced filesystem settings from the dico
     memset(options, 0, sizeof(options));
 
-    strlcatf(options, sizeof(options), " %s ", fsoptions);
-
     if (strlen(mkfslabel) > 0)
         strlcatf(options, sizeof(options), " -L '%.16s' ", mkfslabel);
     else if (dico_get_string(d, 0, FSYSHEADKEY_FSLABEL, buffer, sizeof(buffer))==0 && strlen(buffer)>0)
@@ -67,8 +65,11 @@ int reiser4_mkfs(cdico *d, char *partition, char *fsoptions, char *mkfslabel, ch
         strlcatf(options, sizeof(options), " -U %s ", mkfsuuid);
     else if (dico_get_string(d, 0, FSYSHEADKEY_FSUUID, buffer, sizeof(buffer))==0 && strlen(buffer)==36)
         strlcatf(options, sizeof(options), " -U %s ", buffer);
-    
-    if (exec_command(command, sizeof(command), &exitst, NULL, 0, NULL, 0, "mkfs.reiser4 -y %s %s", partition, options)!=0 || exitst!=0)
+
+    // ---- mkfsopt from command line
+    strlcatf(options, sizeof(options), " %s ", fsoptions);
+
+    if (exec_command(command, sizeof(command), &exitst, NULL, 0, NULL, 0, "mkfs.reiser4 -y %s %s", options, partition)!=0 || exitst!=0)
     {   errprintf("command [%s] failed\n", command);
         return -1;
     }
